You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2014/05/03 20:19:00 UTC

[6/8] git commit: Uses excluded classes to

Uses excluded classes to


Project: http://git-wip-us.apache.org/repos/asf/struts/repo
Commit: http://git-wip-us.apache.org/repos/asf/struts/commit/afb5af1c
Tree: http://git-wip-us.apache.org/repos/asf/struts/tree/afb5af1c
Diff: http://git-wip-us.apache.org/repos/asf/struts/diff/afb5af1c

Branch: refs/heads/feature/exclude-object-class
Commit: afb5af1cc45aed1ee0404541279cb7f7853fc98b
Parents: f0799fd
Author: Lukasz Lenart <lu...@apache.org>
Authored: Sat May 3 20:17:05 2014 +0200
Committer: Lukasz Lenart <lu...@apache.org>
Committed: Sat May 3 20:17:05 2014 +0200

----------------------------------------------------------------------
 core/src/main/java/org/apache/struts2/StrutsConstants.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/struts/blob/afb5af1c/core/src/main/java/org/apache/struts2/StrutsConstants.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/struts2/StrutsConstants.java b/core/src/main/java/org/apache/struts2/StrutsConstants.java
index 6be58ad..d508373 100644
--- a/core/src/main/java/org/apache/struts2/StrutsConstants.java
+++ b/core/src/main/java/org/apache/struts2/StrutsConstants.java
@@ -282,7 +282,7 @@ public final class StrutsConstants {
     /** Allows override default DispatcherErrorHandler **/
     public static final String STRUTS_DISPATCHER_ERROR_HANDLER = "struts.dispatcher.errorHandler";
 
-    /** Comma delimited set of excluded properties which cannot be accessed via expressions **/
-    public static final String STRUTS_EXCLUDED_PROPERTIES = "struts.excludedProperties";
+    /** Comma delimited set of excluded classes which cannot be accessed via expressions **/
+    public static final String STRUTS_EXCLUDED_CLASSES = "struts.excludedClasses";
 
 }